@@ -980,17 +980,21 @@ EXTERN Clipboard_T clip_plus;	// CLIPBOARD selection in X11/Wayland
 #  define clip_plus clip_star	// there is only one clipboard
 #  define ONE_CLIPBOARD
 # endif
+#endif
 
+#ifdef HAVE_CLIPMETHOD
 # define CLIP_UNNAMED      1
 # define CLIP_UNNAMED_PLUS 2
 EXTERN int	clip_unnamed INIT(= 0); // above two values or'ed
 
+# ifdef FEAT_CLIPBOARD
 EXTERN int	clip_autoselect_star INIT(= FALSE);
 EXTERN int	clip_autoselect_plus INIT(= FALSE);
 EXTERN int	clip_autoselectml INIT(= FALSE);
 EXTERN int	clip_html INIT(= FALSE);
 EXTERN regprog_T *clip_exclude_prog INIT(= NULL);
 EXTERN int	clip_unnamed_saved INIT(= 0);
+# endif
 #endif
 
 #ifdef FEAT_CLIPBOARD_PROVIDER
@@ -2021,7 +2025,7 @@ EXTERN listitem_T range_list_item;
 EXTERN evalarg_T EVALARG_EVALUATE
 # ifdef DO_INIT
 	= {EVAL_EVALUATE, 0, NULL, NULL, NULL, NULL, GA_EMPTY, GA_EMPTY, NULL,
-			 {0, 0, (int)sizeof(char_u *), 20, NULL}, 0, NULL}
+			 {0, 0, (int)sizeof(char_u *), 20, NULL}, 0, NULL, NULL}
 # endif
 	;
 #endif
@@ -2130,7 +2134,7 @@ INIT(= CLIENTSERVER_METHOD_NONE);
 EXTERN char_u *client_socket INIT(= NULL);
 #endif
 
-// If the <xOSC> key should be propogated from vgetc()
+// If the <xOSC> key should be propagated from vgetc()
 EXTERN int allow_osc_key INIT(= 0);
 
 #ifdef FEAT_EVAL
@@ -2138,3 +2142,6 @@ EXTERN int allow_osc_key INIT(= 0);
 EXTERN redraw_listener_T *redraw_listeners INIT(= NULL);
 EXTERN bool inside_redraw_on_start_cb INIT(= false);
 #endif
+
+// If greater than zero, then silence the W23/W24 warning.
+EXTERN int silence_w23_w24_msg INIT( = 0);
